function sdot = f_GroundRollDistance_OEI(t,S,...
                    N, m,...
                    Sw,k_TO,h,b,...
                    CD0clean,d_CD0_flaps,d_CD0_gear,CDsp,...
                    CL0,CLalpha,...
                    alpha,gamma,...
                    mu,rho,...
                    vW,...
                    F0,BPR,di,vREL, ...
                    deltaT,H,....
                    lE,lv,Sv,Sr,Av,sweepV) 
                
%   t => independent variable 
%   x => dependent
%        n*2 vector (y / y')

%   y'' = vG' =  a
%   y'  = vG  =  v
%   y   =       s

s  = S(1); 
vG = S(2); % vG = s' 
v  = vG + vW;
% inflow velocity v=vG+vW
% vG=S(2) ground roll speed (regarding runway) [m/s]

N = N-1 ;%  operating engines 

g  = 9.80665;%m/s^2
W  =  m*g;

AR   = b^2/Sw;  % aspect ratio

alphaRad = alpha*pi/180;

gammaRad = gamma*pi/180; 

p0     = 101325;
R      = 287.058;
L      = 0.0065;
T0     = 288.15;
T0     = T0 + deltaT;
kappa  = 1.4;

% Young 2008
p = p0*(1-H*L/T0)^(g/(R*L));
A = -0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ;
X = 0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003;
Z = 0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697;
T = T0-L*H;
c = sqrt(R*kappa*T);

... linear G-factor function: 
G = 0.061*BPR + 0.633; % gas generator factor:Young 2008 => A320, BPR=6
... determined in excel with 2 values of the original figure 
    

K1 = (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0);
K2 = (0.23+0.19*sqrt(BPR)).*X.*p/p0 ;
F   = N*F0*( A - K1*(v/c) + K2*(v/c).^2); %Bartels & Young (genauer - konservativer)

%standard
% k1 = 2.44 * 10^(-4) * BPR  +  1.66 * 10^(-3);
% k2 = 6.16 * 10^(-7) * BPR  +  4.08 * 10^(-6);
%F    = F0*( 1 - k1*v + k2*v^2); %Scholz / Young / Roskam / ...

R    = 0; % reverse thrust
AN  =     pi/4*di^2; % area => inlet, engine

M    = v/c;

... asymmetric flight conditions:
CDwm  = (0.1 + 2./(1+0.16*M^2)*vREL*(1-vREL))*AN/Sw; % (Torenbeek)

              qv = rho*0.5*v^2;
              dF    = (1*F0*( A - K1*(v/c) + K2*(v/c).^2)) + CDwm;
% 
              Cyv = dF / (Sv*qv) *lE/lv;
              CDs = 2.3/pi *sqrt(Sr*Sv)*Av^(-4/3) *cos(sweepV*pi/180)^(1/3)*Cyv^2;
              CDasym = CDs / Sw; % rudder

phi = (16*h/b)^2 / (1+(16*h/b)^2); % ground effect

CLg = CL0 + CLalpha*alphaRad ;
% k     = 1/(pi*e*AR);
% k_TO  = 1/(1/k+pi*AR*delta_e)
L = rho/2*(v)^2*CLg*Sw;
CD0 = CD0clean + d_CD0_flaps + d_CD0_gear + CDasym + CDwm +CDsp;
CDg = CD0 + phi*k_TO*CLg^2 ; 
% CDg = CD0 + phi*k_TO*CLg^2 + CDwm; 
D = rho/2*(v)^2*CDg*Sw; 
Ff = mu*(m*g*cos(gammaRad)-L); 

sdot(1,1) = vG;  % vG = s' =  ds/dt = vG
sdot(2,1) = 1/m*(F-D-Ff)-g*sin(gammaRad); % vG' = s'' = a

return